###Analaysis script for HYPHY RELAX results
##needs input table from RELAX results for immune genes (IGs) "summary_all_IG_relax_w_header.csv"
#and RELAX result tables for genomic background genes (BGs) for each species "summary_all_REFGENES_relax_XXXX_w_header.csv", where XXXX is the species acronym
#these tables can be found in the online supplement

library(lme4)
library(ggplot2)
setwd("path to folder that contains summary_all_IG_relax_w_header.csv and summary_all_REFGENES_relax_XXXX_w_header.csv")

#load RELAX analysis results table for immune genes (IGs)
rlx<-read.csv(file="summary_all_IG_relax_w_header.csv", header=T)

#generate life type grouping variable
summary(rlx$Species_tested)
#Csec  Csp Imar Mdar Mnat Psim Rsan Znev 
#72   16   18   25   53   47   13   78 
#order by species
rlx <- rlx[order(rlx$Species_tested),]

#add lifetype variable
rlx$lifetype<-c(rep("wd",72),rep("f",16),rep("wd",18),rep("f",25),rep("f",53),rep("wd",47),rep("f",13),rep("wd",78))

#add FDR
rlx$fdr<-p.adjust(rlx$p.value,method="BH")
write.csv(rlx,file="RELAXfdr.csv")

#add FDR for BUSTED results
BUSTED<-read.csv("TablethatcontainsthepvaluecolumnfromTableS2")
BUSTED$fdr<-p.adjust(BUSTED$Pvalue,method="BH")
write.csv(BUSTED,file="BUSTEDfdr.csv")

#generate results data frame
rlxks1res<-NULL

#count genes with significantly relaxed selection for each species
sigrlxks1<-rlx[rlx$p.value<0.05 & rlx$par_K<1 & rlx$fdr<0.2,]

rlxks1res$sig<-c(length(sigrlxks1[sigrlxks1=="Psim"]),
length(sigrlxks1[sigrlxks1=="Csec"]),
length(sigrlxks1[sigrlxks1=="Znev"]),
length(sigrlxks1[sigrlxks1=="Imar"]),
length(sigrlxks1[sigrlxks1=="Csp"]),
length(sigrlxks1[sigrlxks1=="Mnat"]),
length(sigrlxks1[sigrlxks1=="Mdar"]),
length(sigrlxks1[sigrlxks1=="Rsan"]))

#count total genes analyzed per species
rlxks1res$total<-c(length(rlx[rlx=="Psim"]),
length(rlx[rlx=="Csec"]),
length(rlx[rlx=="Znev"]),
length(rlx[rlx=="Imar"]),
length(rlx[rlx=="Csp"]),
length(rlx[rlx=="Mnat"]),
length(rlx[rlx=="Mdar"]),
length(rlx[rlx=="Rsan"]))

#calculate ratio of significant genes among total genes analyzed
rlxks1res$ratio<-rlxks1res$sig/rlxks1res$total

#add variables to results table
rlxks1res$lifetype<-c("wd","wd","wd","wd","f","f","f","f")
rlxks1res$species<-c("Psim","Csec","Znev","Imar","Csp","Mnat","Mdar","Rsan")
rlxks1res<-data.frame(rlxks1res$species,rlxks1res$lifetype,rlxks1res$sig,rlxks1res$total,rlxks1res$ratio)
rlxks1res<-as.data.frame(rlxks1res)

###run binomial glmm on counts of significant genes
#model to test for species effects
summary(glM1<-glm(rlxks1res$rlxks1res.ratio~rlxks1res$rlxks1res.species, weights=rlxks1res$rlxks1res.total,family=binomial))
#p=0.08 - 1
#species does not have a significant effect on number of significant genes

#model to test for lifetype effects
glMM2<-glmer(rlxks1res$rlxks1res.ratio~rlxks1res$rlxks1res.lifetype + (1|rlxks1res$rlxks1res.species), weights=rlxks1res$rlxks1res.total,family=binomial)
summary(glMM2)
#p=0.923
### lifetype does not have a significant effect on number of significant genes

#test Zootermopsis nevadensis vs other wood dwellers
#add Zootermopsis variable
rlxks1res$zn<-c("nz","nz","z","nz","nz","nz","nz","nz")
glMZn<-glm(rlxks1res$rlxks1res.ratio[rlxks1res$rlxks1res.lifetype=="wd"]~rlxks1res$zn[rlxks1res$rlxks1res.lifetype=="wd"], weights=rlxks1res$rlxks1res.total[rlxks1res$rlxks1res.lifetype=="wd"],family=binomial)
summary(glMZn)
# p=0.084 Zootermopsis nevadensis does not differ from other wood dwellers

#repeat analysis of life type effects without Znev
glMM2Z<-glmer(rlxks1res$rlxks1res.ratio[rlxks1res$rlxks1res.species!="Znev"]~rlxks1res$rlxks1res.lifetype[rlxks1res$rlxks1res.species!="Znev"] + (1|rlxks1res$rlxks1res.species[rlxks1res$rlxks1res.species!="Znev"]), weights=rlxks1res$rlxks1res.total[rlxks1res$rlxks1res.species!="Znev"],family=binomial)
summary(glMM2Z)
#p=0.606

#test for differences between drywood species and the other species in number of significant genes
#test C. secundus + I. marginipennis vs other species
#add C. secundus + I. marginipennis variable
rlxks1res$ci<-c("nci","ci","nci","ci","nci","nci","nci","nci")
#run model
glMci<-glm(rlxks1res$rlxks1res.ratio~rlxks1res$ci, weights=rlxks1res$rlxks1res.total,family=binomial)
summary(glMci)
#p=0.962

#####
###distributions of the number of significant genes from randomly drawn background genes (BGs) for each species
####
#
###Cryptotermes secundus
#
#load RELAX results for sets of background genes
Csecr<-read.table("summary_all_REFGENES_relax_Csec_w_header.csv",header=T)

#calculate fdr for each set of background genes and add to table
Csecfdr<-NULL

for (i in unique(Csecr$random)){
Csecfdr<-append(Csecfdr,p.adjust(Csecr$p.value[Csecr$random==i],method="BH"))
}

Csecr$fdr<-Csecfdr

#define csec significant background count vector
Csecsrc<-NULL

#count significant loci for each set of background genes
for (i in unique(Csecr$random)){
  Csecsrc[i]<-length(Csecr$p.value[Csecr$random==i & Csecr$p.value<0.05 & Csecr$par_K<1 & Csecr$fdr<0.2])
}

#calculate percentile (pvalue)
CsecP<-length(Csecsrc[Csecsrc>=rlxks1res$rlxks1res.sig[rlxks1res$rlxks1res.species=="Csec"]])/length(Csecsrc)
#p=0.55

##
###Prorhinotermes simplex
##
Psimr<-read.table("summary_all_REFGENES_relax_Psim_w_header.csv",header=T)

#calculate fdr for each set of background genes and add to table
Psimfdr<-NULL

for (i in unique(Psimr$random)){
Psimfdr<-append(Psimfdr,p.adjust(Psimr$p.value[Psimr$random==i],method="BH"))
}

Psimr$fdr<-Psimfdr

#define Psim significant background count vector
Psimsrc<-NULL

#count significant loci for each set of background genes
for (i in unique(Psimr$random)){
  Psimsrc[i]<-length(Psimr$p.value[Psimr$random==i & Psimr$p.value<0.05 & Psimr$par_K<1 & Psimr$fdr<0.2])
}

#calculate percentile (pvalue)
PsimP<-length(Psimsrc[Psimsrc>=rlxks1res$rlxks1res.sig[rlxks1res$rlxks1res.species=="Psim"]])/length(Psimsrc)
#p=0.78
##
###Zootermopsis nevadensis
##
Znevr<-read.table("summary_all_REFGENES_relax_Znev_w_header.csv",header=T)

#calculate fdr for each set of background genes and add to table
Znevfdr<-NULL

for (i in unique(Znevr$random)){
Znevfdr<-append(Znevfdr,p.adjust(Znevr$p.value[Znevr$random==i],method="BH"))
}

Znevr$fdr<-Znevfdr

#define Znev significant background count vector
Znevsrc<-NULL

#count significant loci for each set of background genes
for (i in unique(Znevr$random)){
  Znevsrc[i]<-length(Znevr$p.value[Znevr$random==i & Znevr$p.value<0.05 & Znevr$par_K<1 & Znevr$fdr<0.2])
}

#calculate percentile (pvalue)
ZnevP<-length(Znevsrc[Znevsrc>=rlxks1res$rlxks1res.sig[rlxks1res$rlxks1res.species=="Znev"]])/length(Znevsrc)
#p=0.84

##
###Incisitermes marginipennis
##
Imarr<-read.table("summary_all_REFGENES_relax_Imar_w_header.csv",header=T)

#calculate fdr for each set of background genes and add to table
Imarfdr<-NULL

for (i in unique(Imarr$random)){
Imarfdr<-append(Imarfdr,p.adjust(Imarr$p.value[Imarr$random==i],method="BH"))
}

Imarr$fdr<-Imarfdr

#define Imar significant background count vector
Imarsrc<-NULL

#count significant loci for each set of background genes
for (i in unique(Imarr$random)){
  Imarsrc[i]<-length(Imarr$p.value[Imarr$random==i & Imarr$p.value<0.05 & Imarr$par_K<1 & Imarr$fdr<0.2])
}

#calculate percentile (pvalue)
ImarP<-length(Imarsrc[Imarsrc>=rlxks1res$rlxks1res.sig[rlxks1res$rlxks1res.species=="Imar"]])/length(Imarsrc)
#p=1

##
###Coptotermes spp.
##
Cspr<-read.table("summary_all_REFGENES_relax_Csp_w_header.csv",header=T)

#calculate fdr for each set of background genes and add to table
Cspfdr<-NULL

for (i in unique(Cspr$random)){
Cspfdr<-append(Cspfdr,p.adjust(Cspr$p.value[Cspr$random==i],method="BH"))
}

Cspr$fdr<-Cspfdr

#define Csp significant background count vector
Cspsrc<-NULL

#count significant loci for each set of background genes
for (i in unique(Cspr$random)){
  Cspsrc[i]<-length(Cspr$p.value[Cspr$random==i & Cspr$p.value<0.05 & Cspr$par_K<1 & Cspr$fdr<0.2])
}

#calculate percentile (pvalue)
CspP<-length(Cspsrc[Cspsrc>=rlxks1res$rlxks1res.sig[rlxks1res$rlxks1res.species=="Csp"]])/length(Cspsrc)
#p=0.9

##
###Macrotermes natalensis
##
Mnatr<-read.table("summary_all_REFGENES_relax_Mnat_w_header.csv",header=T)

#calculate fdr for each set of background genes and add to table
Mnatfdr<-NULL

for (i in unique(Mnatr$random)){
Mnatfdr<-append(Mnatfdr,p.adjust(Mnatr$p.value[Mnatr$random==i],method="BH"))
}

Mnatr$fdr<-Mnatfdr

#define Mnat significant background count vector
Mnatsrc<-NULL

#count significant loci for each set of background genes
for (i in unique(Mnatr$random)){
  Mnatsrc[i]<-length(Mnatr$p.value[Mnatr$random==i & Mnatr$p.value<0.05 & Mnatr$par_K<1 & Mnatr$fdr<0.2])
}

#calculate percentile (pvalue)
MnatP<-length(Mnatsrc[Mnatsrc>=rlxks1res$rlxks1res.sig[rlxks1res$rlxks1res.species=="Mnat"]])/length(Mnatsrc)
#p=0.76

##
###Mastotermes darwiniensis
##
Mdarr<-read.table("summary_all_REFGENES_relax_Mdar_w_header.csv",header=T)

#calculate fdr for each set of background genes and add to table
Mdarfdr<-NULL

for (i in unique(Mdarr$random)){
Mdarfdr<-append(Mdarfdr,p.adjust(Mdarr$p.value[Mdarr$random==i],method="BH"))
}

Mdarr$fdr<-Mdarfdr


#define Mdar significant background count vector
Mdarsrc<-NULL

#count significant loci for each set of background genes
for (i in unique(Mdarr$random)){
  Mdarsrc[i]<-length(Mdarr$p.value[Mdarr$random==i & Mdarr$p.value<0.05 & Mdarr$par_K<1 & Mdarr$fdr<0.2])
}

#calculate percentile (pvalue)
MdarP<-length(Mdarsrc[Mdarsrc>=rlxks1res$rlxks1res.sig[rlxks1res$rlxks1res.species=="Mdar"]])/length(Mdarsrc)
#p=0.54

##
###Reticulitermes santonensis
##
Rsanr<-read.table("summary_all_REFGENES_relax_Rsan_w_header.csv",header=T)

#define Rsan significant background count vector
Rsansrc<-NULL

#calculate fdr for each set of background genes and add to table
Rsanfdr<-NULL

for (i in unique(Rsanr$random)){
Rsanfdr<-append(Rsanfdr,p.adjust(Rsanr$p.value[Rsanr$random==i],method="BH"))
}

Rsanr$fdr<-Rsanfdr

#count significant loci for each set of background genes
for (i in unique(Rsanr$random)){
  Rsansrc[i]<-length(Rsanr$p.value[Rsanr$random==i & Rsanr$p.value<0.05 & Rsanr$par_K<1 & Rsanr$fdr<0.2])
}

#calculate percentile (pvalue)
RsanP<-length(Rsansrc[Rsansrc>=rlxks1res$rlxks1res.sig[rlxks1res$rlxks1res.species=="Rsan"]])/length(Rsansrc)
#p=0.64

#
##add results from number of significant BG loci analysis to results table
#
#add median number of significant loci per species
rlxks1res$signlocimed<-c(median(Psimsrc),median(Csecsrc),median(Znevsrc),median(Imarsrc),median(Cspsrc),median(Mnatsrc),median(Mdarsrc),median(Rsansrc))

#add 95%confidence intervals
rlxks1res$signlociq95<-c(quantile(Psimsrc,0.975),quantile(Csecsrc,0.975),quantile(Znevsrc,0.975),quantile(Imarsrc,0.975),quantile(Cspsrc,0.975),quantile(Mnatsrc,0.975),quantile(Mdarsrc,0.975),quantile(Rsansrc,0.975))
rlxks1res$signlociq05<-c(quantile(Psimsrc,0.025),quantile(Csecsrc,0.025),quantile(Znevsrc,0.025),quantile(Imarsrc,0.025),quantile(Cspsrc,0.025),quantile(Mnatsrc,0.025),quantile(Mdarsrc,0.025),quantile(Rsansrc,0.025))

####
## get distribution for ratio #significant genes in wood dwellers/#significant genes in foragers as a test statistic
###
ratiowdfdist<-NULL
sumwd<-NULL
sumf<-NULL

for (i in 1:100){
    sumwd<-sum(length(Psimr$p.value[Psimr$random==unique(Psimr$random)[i] & Psimr$p.value<0.05 & Psimr$par_K<1 & Psimr$fdr<0.2]),
    length(Csecr$p.value[Csecr$random==unique(Csecr$random)[i] & Csecr$p.value<0.05 & Csecr$par_K<1 & Csecr$fdr<0.2]),
    length(Znevr$p.value[Znevr$random==unique(Znevr$random)[i] & Znevr$p.value<0.05 & Znevr$par_K<1 & Znevr$fdr<0.2]),
    length(Imarr$p.value[Imarr$random==unique(Imarr$random)[i] & Imarr$p.value<0.05 & Imarr$par_K<1 & Imarr$fdr<0.2]))

    sumf<-sum(length(Cspr$p.value[Cspr$random==unique(Cspr$random)[i] & Cspr$p.value<0.05 & Cspr$par_K<1 & Cspr$fdr<0.2]),
          length(Mnatr$p.value[Mnatr$random==unique(Mnatr$random)[i] & Mnatr$p.value<0.05 & Mnatr$par_K<1 & Mnatr$fdr<0.2]),
          length(Mdarr$p.value[Mdarr$random==unique(Mdarr$random)[i] & Mdarr$p.value<0.05 & Mdarr$par_K<1 & Mdarr$fdr<0.2]),
          length(Rsanr$p.value[Rsanr$random==unique(Rsanr$random)[i] & Rsanr$p.value<0.05 & Rsanr$par_K<1 & Rsanr$fdr<0.2]))

    ratiowdfdist[i]<-sumwd/sumf
}

#calculate wd/f of significant immune genes IGs
ratiosigwdf<-sum(rlxks1res$rlxks1res.sig[rlxks1res$rlxks1res.lifetype=="wd"])/sum(rlxks1res$rlxks1res.sig[rlxks1res$rlxks1res.lifetype=="f"])

#calculate percentile (pvalue) for IGs in the BG distribution
ratiowdfdistP<-length(ratiowdfdist[ratiowdfdist>=ratiosigwdf])/length(ratiowdfdist)
hist(ratiowdfdist)
#p=0.43


###############
#### analysis of the selection intensity parameter k
###############

#test if there are differences between species
kruskal.test(rlx$par_K ~ rlx$Species_tested)
#p=0.785
#test if there are differences between species among wood-dwellers
kruskal.test(rlx$par_K[rlx$lifetype=="wd"]~ rlx$Species_tested[rlx$lifetype=="wd"])
#p=0.7539
#test if there are differences between species among foragers
kruskal.test(rlx$par_K[rlx$lifetype=="f"]~ rlx$Species_tested[rlx$lifetype=="f"])
#p=0.4762
#==> it is probably fair to group the species together by life type

#test Znev versus rest
wilcox.test(rlx$par_K[rlx$Species_tested=="Znev"], rlx$par_K[rlx$Species_tested!="Znev"])
#p=0.879 

#test Znev versus other wood dwellers
wilcox.test(rlx$par_K[rlx$Species_tested=="Znev"], rlx$par_K[rlx$Species_tested!="Znev" & rlx$lifetype == "wd"])
#p=0.7713
length(rlx$par_K[rlx$lifetype == "wd"])
#n=215

#calculate median K for wood dwellers and foragers
tapply(rlx$par_K,rlx$lifetype,median)

#    f        wd 
#0.7696684 0.7423480 

#test if parameter K is lower in wood dwellers
#check factor order for one-sided test
levels(as.factor(rlx$lifetype))
#"f"  "wd"
wilcox.test(rlx$par_K~rlx$lifetype, alternative="g")
##p=0.4061

#test Cryptotermes + Incisitermes versus others
wilcox.test(rlx$par_K[rlx$Species_tested=="Csec" | rlx$Species_tested=="Imar"], rlx$par_K[rlx$Species_tested!="Csec" & rlx$lifetype != "Imar"])
#p=0.3732
length(rlx$par_K[rlx$lifetype == "wd"])
#n=322

#test for overall signal of relaxation 
#is k is smaller than 1?
median(rlx$par_K)
wilcox.test(rlx$par_K,mu=1)
##p = 0.0094

#####
###distributions from sets of background genes (BGs) for k per species
####
#
###Cryptotermes secundus
#
#read table with RELAX results from sets of BGs
Csecr<-read.table("summary_all_REFGENES_relax_Csec_w_header.csv",header=T)
#test if k for IGs differs from k for BGs
tes<-wilcox.test(rlx$par_K[rlx$Species_tested=="Csec"],Csecr$par_K)
CsecrPar_kp<-tes$p.value

#get median k from 100 BG sets
Csecrkdist<-NULL
for (i in unique(Csecr$random)){
  Csecrkdist[i]<-median(Csecr$par_K[Csecr$random==i])
}

#
###Prorhinotermes simplex
#
Psimr<-read.table("summary_all_REFGENES_relax_Psim_w_header.csv",header=T)
tes<-wilcox.test(rlx$par_K[rlx$Species_tested=="Psim"],Psimr$par_K)
PsimrPar_kp<-tes$p.value

#get median k from 100 BG sets
Psimrkdist<-NULL
for (i in unique(Psimr$random)){
  Psimrkdist[i]<-median(Psimr$par_K[Psimr$random==i])
}

#
###Zootermopsis nevadensis
#
Znevr<-read.table("summary_all_REFGENES_relax_Znev_w_header.csv",header=T)
tes<-wilcox.test(rlx$par_K[rlx$Species_tested=="Znev"],Znevr$par_K)
ZnevrPar_kp<-tes$p.value

#get median k from 100 BG sets
Znevrkdist<-NULL
for (i in unique(Znevr$random)){
  Znevrkdist[i]<-median(Znevr$par_K[Znevr$random==i])
}

#
###Incisitermes marginipennis
#
Imarr<-read.table("summary_all_REFGENES_relax_Imar_w_header.csv",header=T)
tes<-wilcox.test(rlx$par_K[rlx$Species_tested=="Imar"],Imarr$par_K)
ImarrPar_kp<-tes$p.value

#get median k from 100 BG sets
Imarrkdist<-NULL
for (i in unique(Imarr$random)){
  Imarrkdist[i]<-median(Imarr$par_K[Imarr$random==i])
}

#
###Coptotermes spp
#
Cspr<-read.table("summary_all_REFGENES_relax_Csp_w_header.csv",header=T)
tes<-wilcox.test(rlx$par_K[rlx$Species_tested=="Csp"],Cspr$par_K)
CsprPar_kp<-tes$p.value

#get median k from 100 BG sets
Csprkdist<-NULL
for (i in unique(Cspr$random)){
  Csprkdist[i]<-median(Cspr$par_K[Cspr$random==i])
}

#
###Macrotermes natalensis
#
Mnatr<-read.table("summary_all_REFGENES_relax_Mnat_w_header.csv",header=T)
tes<-wilcox.test(rlx$par_K[rlx$Species_tested=="Mnat"],Mnatr$par_K)
MnatrPar_kp<-tes$p.value

#get median k from 100 BG sets
Mnatrkdist<-NULL
for (i in unique(Mnatr$random)){
  Mnatrkdist[i]<-median(Mnatr$par_K[Mnatr$random==i])
}

#
###Mastotermes darwiniensis
#
Mdarr<-read.table("summary_all_REFGENES_relax_Mdar_w_header.csv",header=T)
tes<-wilcox.test(rlx$par_K[rlx$Species_tested=="Mdar"],Mdarr$par_K)
MdarrPar_kp<-tes$p.value

#get median k from 100 BG sets
Mdarrkdist<-NULL
for (i in unique(Mdarr$random)){
  Mdarrkdist[i]<-median(Mdarr$par_K[Mdarr$random==i])
}

#
###Reticulitermes santonensis
#
Rsanr<-read.table("summary_all_REFGENES_relax_Rsan_w_header.csv",header=T)
tes<-wilcox.test(rlx$par_K[rlx$Species_tested=="Rsan"],Rsanr$par_K)
RsanrPar_kp<-tes$p.value

#get median k from 100 BG sets
Rsanrkdist<-NULL
for (i in unique(Rsanr$random)){
  Rsanrkdist[i]<-median(Rsanr$par_K[Rsanr$random==i])
}

###
##Are there differences in selection intensity (k) between IGs and BGs?
##

#get median k from BGs per species and add to results table
rlxks1res$medRG_k<-c(median(Psimrkdist),median(Csecrkdist),median(Znevrkdist),median(Imarrkdist),median(Csprkdist),median(Mnatrkdist),median(Mdarrkdist),median(Rsanrkdist))

#get 95% CI for k from BGs per species and add to results table
rlxks1res$RG_k975<-c(quantile(Psimrkdist,0.975),quantile(Csecrkdist,0.975),quantile(Znevrkdist,0.975),quantile(Imarrkdist,0.975),quantile(Csprkdist,0.975),quantile(Mnatrkdist,0.975),quantile(Mdarrkdist,0.975),quantile(Rsanrkdist,0.975))
rlxks1res$RG_k025<-c(quantile(Psimrkdist,0.025),quantile(Csecrkdist,0.025),quantile(Znevrkdist,0.025),quantile(Imarrkdist,0.025),quantile(Csprkdist,0.025),quantile(Mnatrkdist,0.025),quantile(Mdarrkdist,0.025),quantile(Rsanrkdist,0.025))

###add pvalues for tests between IGs and BGs to results table
rlxks1res$par_KIGvsRG<-c(PsimrPar_kp,CsecrPar_kp,ZnevrPar_kp,ImarrPar_kp,CsprPar_kp,MnatrPar_kp,MdarrPar_kp,RsanrPar_kp)

##calculate median k per species from IGs and add to table
#reorder to make table fit the tapply results
rlxks1res<-rlxks1res[order(rlxks1res$rlxks1res.species),]
rlxks1res$par_kmed<-tapply(rlx$par_K,rlx$Species_tested,median)

#add 95% CIs
lowerCI<-function(x){quantile(x,0.025)}
rlxks1res$par_kmedIG_LCI<-tapply(rlx$par_K,rlx$Species_tested,lowerCI)
upperCI<-function(x){quantile(x,0.975)}
rlxks1res$par_kmedIG_UCI<-tapply(rlx$par_K,rlx$Species_tested,upperCI)

#reorder by life type to make table look nice again
rlxks1res<-rlxks1res[order(rlxks1res$rlxks1res.lifetype),]

#export table 1 base table
write.csv(rlxks1res,file="relaxanalysisresultsRevision.csv")

####
## get distribution for ratio of k wd/f from 100 sets of BGs
###
ratioKwdfdist<-NULL

for (i in 1:100){
ratioKwdfdist[i]<-median(c(Psimr$par_K[Psimr$random==unique(Psimr$random)[i]],Csecr$par_K[Csecr$random==unique(Csecr$random)[i]],Znevr$par_K[Znevr$random==unique(Znevr$random)[i]],Imarr$par_K[Imarr$random==unique(Imarr$random)[i]]))/median(c(Cspr$par_K[Cspr$random==unique(Cspr$random)[i]],Mnatr$par_K[Mnatr$random==unique(Mnatr$random)[i]],Mdarr$par_K[Mdarr$random==unique(Mdarr$random)[i]],Rsanr$par_K[Rsanr$random==unique(Rsanr$random)[i]]))
}

#calculate k wd/f for IGs
ratioKwdf<-median(rlx$par_K[rlx$lifetype=="wd"])/median(rlx$par_K[rlx$lifetype=="f"])

#calculate percentile (pvalue) for IGs in BG distribution
ratiowdfdistP<-length(ratioKwdfdist[ratioKwdfdist<=ratioKwdf])/length(ratioKwdfdist)
#p=0.16

###test if median of BG sets are smaller than 1 (genome wide relaxation on each termite branch)
RGks1P<-c(wilcox.test(Psimrkdist,mu=1)$p.value,wilcox.test(Znevrkdist,mu=1)$p.value,wilcox.test(Imarrkdist,mu=1)$p.value,wilcox.test(Csprkdist,mu=1)$p.value,wilcox.test(Mnatrkdist,mu=1)$p.value,wilcox.test(Mdarrkdist,mu=1)$p.value,wilcox.test(Rsanrkdist,mu=1)$p.value,wilcox.test(Csecrkdist,mu=1)$p.value)
range(RGks1P)


##############
#####PLOT
##############

#prepare data frame with empiric value of wd/f significant genes and ration k for wd/f
pointdata2<-data.frame(Kp=c("#sign genes wd/f","Par k wd/f"),ratios=c(sum(rlxks1res$rlxks1res.sig[rlxks1res$rlxks1res.lifetype=="wd"])/sum(rlxks1res$rlxks1res.sig[rlxks1res$rlxks1res.lifetype=="f"]),ratioKwdf<-median(rlx$par_K[rlx$lifetype=="wd"])/median(rlx$par_K[rlx$lifetype=="f"])))

#prepare data frames with distributions based on reference genes
dat<-data.frame(ratiowdfdist=c(ratiowdfdist,ratioKwdfdist),dummy=c(rep("#sign genes wd/f",length(ratiowdfdist)),c(rep("Par k wd/f",length(ratioKwdfdist)))))
dat2<-dat[dat$dummy=="#sign genes wd/f",]
pointdata3<-pointdata2[pointdata2$Kp=="#sign genes wd/f",]
dat3<-dat[dat$dummy=="Par k wd/f",]
pointdata4<-pointdata2[pointdata2$Kp=="Par k wd/f",]

#plot Figure 2A
svg(filename="Figure2ARevision.svg",width=2,height=6,pointsize=12)

ggplot(dat2, aes(x = dummy, y = ratiowdfdist)) + 
  labs(y = "relative number of genes under relaxed purifying selection (wd/f)", x = "") +
  geom_violin() +
  geom_point(data = pointdata3, shape = "-", size = 30, color="red", aes(x = Kp, y = ratios)) +
geom_jitter(position = position_jitter(0.2), colour = "black")

dev.off()  

#plot Figure 2B
svg(filename="Figure2BRevision.svg",width=2,height=6,pointsize=12)
ggplot(dat3, aes(x = dummy, y = ratiowdfdist)) + 
  labs(y = "relative intensity of purifying selection (wd/f)", x = "") +
  geom_violin() +
  geom_point(data = pointdata4, shape = "-", size = 30, color="red", aes(x = Kp, y = ratios)) +
geom_jitter(position = position_jitter(0.2), colour = "black")

dev.off()  